.. _optics_description:

Optics Description
==================

The `~ctapipe.instrument.OpticsDescription` class holds info about the telescope structure and
mirror, in particular the telescope structure type and sub-type (e.g. 'SST' ->'GCT')


Reference/API
-------------

.. automodapi:: ctapipe.instrument.optics
    :no-inheritance-diagram:
